# Reconstructing HDR Images using Non-Learning and Deep Learning Based Multi-exposure Image Synthesis Techniques

## Authors
Bin (Claire) Zhang: zhangbin@stanford.edu

Megan Zhang: lzhang8@stanford.edu

Affiliation: Department of Electrical Engineering, Stanford University

Course: EE367 Computational Imaging

## Directory Structure
    .
    ├── data                        # Data for the learning based method
        ├── HDR                     # HDR radiance map ground truth
            ├── HDR_001.hdr  
            ├── ...
        ├── LDR_exposure_+2         # LDR image
            ├── LDR_001.jpg  
            ├── ...
        ├── LDR_exposure_-2         # LDR image
            ├── LDR_001.jpg  
            ├── ...
        ├── LDR_exposure_0          # LDR image
            ├── LDR_001.jpg  
            ├── ...
    ├── non_learning_fusion_method  # non-learning based method file and data
        ├── hdr_data                # data for evaluating non-learning fusion method
        ├── hdr_fusion.py           # non-learning fusion algorithm  
    ├── gather_test_result.ipynb    # run evaluation, save test results
    ├── plot_train_curve.ipynb      # plot trainind and evaluation curves
    ├── dataloader.py               # dataloader
    ├── environment.yml             # dependency
    ├── main.py                     # training loop
    ├── README.md
    └── UNet.py                     # UNet architecture

## Run Repo
Clone repo

```
git clone https://github.com/clairezb/367_HDR.git
```
- Run non-learning based fusion algorithm

```
./non_learning_fusion_method/hdr_fusion.py
```

- Run learning-based method

Install dependencies

```
environment.yml
```

Train

```
main.py
```

Evaluate

```
gather_test_result.ipynb
```

## Data

Download data from the following link and put data in the ./data folder

```
https://github.com/edwin-pan/MetaHDR/blob/main/data.md
```




